@@ -56,7 +56,7 @@ void FancyTabProxyStyle::drawControl(
     QPainter* p, const QWidget* widget) const
 {
 
-    const QStyleOptionTab* v_opt = qstyleoption_cast<const QStyleOptionTab*>(option);
+    const auto* v_opt = qstyleoption_cast<const QStyleOptionTab*>(option);
 
     if (element != CE_TabBarTab || !v_opt) {
         QProxyStyle::drawControl(element, option, p, widget);
@@ -122,15 +122,15 @@ void FancyTabProxyStyle::drawControl(
     p->drawText(text_rect, textFlags, text);
     p->setPen(selected ? QColor(60, 60, 60) : Utils::StyleHelper::panelTextColor());
     if (widget) {
-        const QString fader_key = "tab_" + text + "_fader";
-        const QString animation_key = "tab_" + text + "_animation";
+        const QString fader_key = QSL("tab_") + text + QSL("_fader");
+        const QString animation_key = QSL("tab_") + text + QSL("_animation");
 
         const QString tab_hover = widget->property("tab_hover").toString();
         int fader = widget->property(fader_key.toUtf8().constData()).toInt();
-        QPropertyAnimation* animation = widget->property(animation_key.toUtf8().constData()).value<QPropertyAnimation*>();
+        auto* animation = widget->property(animation_key.toUtf8().constData()).value<QPropertyAnimation*>();
 
         if (!animation) {
-            QWidget* mut_widget = const_cast<QWidget*>(widget);
+            auto* mut_widget = const_cast<QWidget*>(widget);
             fader = 0;
             mut_widget->setProperty(fader_key.toUtf8().constData(), fader);
             animation = new QPropertyAnimation(mut_widget, fader_key.toUtf8(), mut_widget);
@@ -174,7 +174,7 @@ void FancyTabProxyStyle::drawControl(
 
 void FancyTabProxyStyle::polish(QWidget* widget)
 {
-    if (QString(widget->metaObject()->className()) == QLatin1String("QTabBar")) {
+    if (QString::fromLatin1(widget->metaObject()->className()) == QLatin1String("QTabBar")) {
         widget->setMouseTracking(true);
         widget->installEventFilter(this);
     }
@@ -193,9 +193,9 @@ void FancyTabProxyStyle::polish(QPalette &palette)
 
 bool FancyTabProxyStyle::eventFilter(QObject* o, QEvent* e)
 {
-    QTabBar* bar = qobject_cast<QTabBar*>(o);
+    auto* bar = qobject_cast<QTabBar*>(o);
     if (bar && (e->type() == QEvent::MouseMove || e->type() == QEvent::Leave)) {
-        QMouseEvent* event = static_cast<QMouseEvent*>(e);
+        auto* event = static_cast<QMouseEvent*>(e);
         const QString old_hovered_tab = bar->property("tab_hover").toString();
         const QString hovered_tab = e->type() == QEvent::Leave ? QString() : bar->tabText(bar->tabAt(event->pos()));
         bar->setProperty("tab_hover", hovered_tab);
@@ -250,14 +250,14 @@ FancyTabBar::FancyTabBar(QWidget* parent)
     setMouseTracking(true); // Needed for hover events
     m_triggerTimer.setSingleShot(true);
 
-    QVBoxLayout* layout = new QVBoxLayout;
+    auto* layout = new QVBoxLayout;
     layout->addSpacerItem(new QSpacerItem(0, 0, QSizePolicy::Fixed, QSizePolicy::Expanding));
     layout->setSpacing(0);
     layout->setContentsMargins(0, 0, 0, 0);
     setLayout(layout);
 
     // We use a zerotimer to keep the sidebar responsive
-    connect(&m_triggerTimer, SIGNAL(timeout()), this, SLOT(emitCurrentIndex()));
+    connect(&m_triggerTimer, &QTimer::timeout, this, &FancyTabBar::emitCurrentIndex);
 }
 
 FancyTabBar::~FancyTabBar()
@@ -348,7 +348,7 @@ void FancyTabBar::setTabToolTip(int index, const QString &toolTip)
 // mode itself
 void FancyTabBar::emitCurrentIndex()
 {
-    emit currentChanged(m_currentIndex);
+    Q_EMIT currentChanged(m_currentIndex);
 }
 
 void FancyTabBar::mousePressEvent(QMouseEvent* e)
@@ -366,7 +366,7 @@ void FancyTabBar::mousePressEvent(QMouseEvent* e)
 
 void FancyTabBar::addTab(const QIcon &icon, const QString &label)
 {
-    FancyTab* tab = new FancyTab(this);
+    auto* tab = new FancyTab(this);
     tab->icon = icon;
     tab->text = label;
     m_tabs.append(tab);
@@ -460,7 +460,7 @@ void FancyTabBar::setCurrentIndex(int index)
 {
     m_currentIndex = index;
     update();
-    emit currentChanged(m_currentIndex);
+    Q_EMIT currentChanged(m_currentIndex);
 }
 
 
@@ -476,7 +476,7 @@ public:
         setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
     }
 
-    void mousePressEvent(QMouseEvent* ev) {
+    void mousePressEvent(QMouseEvent* ev) override {
         if (ev->modifiers() & Qt::ShiftModifier) {
             Utils::StyleHelper::setBaseColor(QColorDialog::getColor(Utils::StyleHelper::requestedBaseColor(), m_parent));
         }
@@ -492,28 +492,28 @@ private:
 FancyTabWidget::FancyTabWidget(QWidget* parent)
     : QWidget(parent),
       mode_(Mode_None),
-      tab_bar_(NULL),
+      tab_bar_(nullptr),
       stack_(new QStackedLayout),
       side_widget_(new QWidget),
       side_layout_(new QVBoxLayout),
       top_layout_(new QVBoxLayout),
       use_background_(false),
-      menu_(NULL),
+      menu_(nullptr),
       proxy_style_(new FancyTabProxyStyle)
 {
     side_layout_->setSpacing(0);
-    side_layout_->setMargin(0);
+    side_layout_->setContentsMargins(0, 0, 0, 0);
     side_layout_->addSpacerItem(new QSpacerItem(0, 0, QSizePolicy::Fixed, QSizePolicy::Expanding));
 
     side_widget_->setLayout(side_layout_);
     side_widget_->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
 
-    top_layout_->setMargin(0);
+    top_layout_->setContentsMargins(0, 0, 0, 0);
     top_layout_->setSpacing(0);
     top_layout_->addLayout(stack_);
 
-    QHBoxLayout* main_layout = new QHBoxLayout;
-    main_layout->setMargin(0);
+    auto* main_layout = new QHBoxLayout;
+    main_layout->setContentsMargins(0, 0, 0, 0);
     main_layout->setSpacing(1);
     main_layout->addWidget(side_widget_);
     main_layout->addLayout(top_layout_);
@@ -576,10 +576,10 @@ int FancyTabWidget::current_index() const
 
 void FancyTabWidget::SetCurrentIndex(int index)
 {
-    if (FancyTabBar* bar = qobject_cast<FancyTabBar*>(tab_bar_)) {
+    if (auto* bar = qobject_cast<FancyTabBar*>(tab_bar_)) {
         bar->setCurrentIndex(index);
     }
-    else if (QTabBar* bar = qobject_cast<QTabBar*>(tab_bar_)) {
+    else if (auto* bar = qobject_cast<QTabBar*>(tab_bar_)) {
         bar->setCurrentIndex(index);
     }
     else {
@@ -590,7 +590,7 @@ void FancyTabWidget::SetCurrentIndex(int index)
 void FancyTabWidget::ShowWidget(int index)
 {
     stack_->setCurrentIndex(index);
-    emit CurrentChanged(index);
+    Q_EMIT CurrentChanged(index);
 }
 
 void FancyTabWidget::AddBottomWidget(QWidget* widget)
@@ -602,7 +602,7 @@ void FancyTabWidget::SetMode(Mode mode)
 {
     // Remove previous tab bar
     delete tab_bar_;
-    tab_bar_ = NULL;
+    tab_bar_ = nullptr;
 
     use_background_ = false;
 
@@ -614,7 +614,7 @@ void FancyTabWidget::SetMode(Mode mode)
         // fallthrough
 
     case Mode_LargeSidebar: {
-        FancyTabBar* bar = new FancyTabBar(this);
+        auto* bar = new FancyTabBar(this);
         side_layout_->insertWidget(0, bar);
         tab_bar_ = bar;
 
@@ -628,7 +628,7 @@ void FancyTabWidget::SetMode(Mode mode)
         }
 
         bar->setCurrentIndex(stack_->currentIndex());
-        connect(bar, SIGNAL(currentChanged(int)), SLOT(ShowWidget(int)));
+        connect(bar, &FancyTabBar::currentChanged, this, &FancyTabWidget::ShowWidget);
 
         use_background_ = true;
 
@@ -656,7 +656,7 @@ void FancyTabWidget::SetMode(Mode mode)
     tab_bar_->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
 
     mode_ = mode;
-    emit ModeChanged(mode);
+    Q_EMIT ModeChanged(mode);
     update();
 }
 
@@ -697,7 +697,7 @@ void FancyTabWidget::AddMenuItem(QSignalMapper* mapper, QActionGroup* group,
 void FancyTabWidget::MakeTabBar(QTabBar::Shape shape, bool text, bool icons,
                                 bool fancy)
 {
-    QTabBar* bar = new QTabBar(this);
+    auto* bar = new QTabBar(this);
     bar->setShape(shape);
     bar->setDocumentMode(true);
     bar->setUsesScrollButtons(true);
@@ -742,6 +742,6 @@ void FancyTabWidget::MakeTabBar(QTabBar::Shape shape, bool text, bool icons,
     }
 
     bar->setCurrentIndex(stack_->currentIndex());
-    connect(bar, SIGNAL(currentChanged(int)), SLOT(ShowWidget(int)));
+    connect(bar, &QTabBar::currentChanged, this, &FancyTabWidget::ShowWidget);
     tab_bar_ = bar;
 }
