@@ -87,8 +87,7 @@
 static const int savedWindowVersion = 2;
 
 BrowserWindow::SavedWindow::SavedWindow()
-{
-}
+= default;
 
 BrowserWindow::SavedWindow::SavedWindow(BrowserWindow *window)
 {
@@ -190,18 +189,18 @@ QDataStream &operator>>(QDataStream &stream, BrowserWindow::SavedWindow &window)
 }
 
 BrowserWindow::BrowserWindow(Qz::BrowserWindowType type, const QUrl &startUrl)
-    : QMainWindow(0)
+    : QMainWindow(nullptr)
     , m_startUrl(startUrl)
     , m_windowType(type)
-    , m_startTab(0)
-    , m_startPage(0)
+    , m_startTab(nullptr)
+    , m_startPage(nullptr)
     , m_sideBarManager(new SideBarManager(this))
-    , m_hideNavigationTimer(0)
+    , m_hideNavigationTimer(nullptr)
 {
     setAttribute(Qt::WA_DeleteOnClose);
     setAttribute(Qt::WA_DontCreateNativeAncestors);
 
-    setObjectName("mainwindow");
+    setObjectName(QSL("mainwindow"));
     setWindowTitle(tr("Falkon"));
     setProperty("private", mApp->isPrivate());
 
@@ -211,17 +210,17 @@ BrowserWindow::BrowserWindow(Qz::BrowserWindowType type, const QUrl &startUrl)
     m_hideNavigationTimer = new QTimer(this);
     m_hideNavigationTimer->setInterval(1000);
     m_hideNavigationTimer->setSingleShot(true);
-    connect(m_hideNavigationTimer, SIGNAL(timeout()), this, SLOT(hideNavigationSlot()));
+    connect(m_hideNavigationTimer, &QTimer::timeout, this, &BrowserWindow::hideNavigationSlot);
 
-    connect(mApp, SIGNAL(settingsReloaded()), this, SLOT(loadSettings()));
+    connect(mApp, &MainApplication::settingsReloaded, this, &BrowserWindow::loadSettings);
 
-    QTimer::singleShot(0, this, SLOT(postLaunch()));
+    QTimer::singleShot(0, this, &BrowserWindow::postLaunch);
 
     if (mApp->isPrivate()) {
-        QzTools::setWmClass("Falkon Browser (Private Window)", this);
+        QzTools::setWmClass(QSL("Falkon Browser (Private Window)"), this);
     }
     else {
-        QzTools::setWmClass("Falkon Browser", this);
+        QzTools::setWmClass(QSL("Falkon Browser"), this);
     }
 }
 
@@ -229,7 +228,7 @@ BrowserWindow::~BrowserWindow()
 {
     mApp->plugins()->emitMainWindowDeleted(this);
 
-    foreach (const QPointer<QWidget> &pointer, m_deleteOnCloseWidgets) {
+    for (const QPointer<QWidget> &pointer : qAsConst(m_deleteOnCloseWidgets)) {
         if (pointer) {
             pointer->deleteLater();
         }
@@ -259,7 +258,7 @@ void BrowserWindow::postLaunch()
         break;
 
     case MainApplication::OpenSpeedDial:
-        startUrl = QUrl("falkon:speeddial");
+        startUrl = QUrl(QSL("falkon:speeddial"));
         break;
 
     case MainApplication::OpenHomePage:
@@ -281,7 +280,7 @@ void BrowserWindow::postLaunch()
         if (mApp->isStartingAfterCrash()) {
             addTab = false;
             startUrl.clear();
-            m_tabWidget->addView(QUrl("falkon:restore"), Qz::NT_CleanSelectedTabAtTheEnd);
+            m_tabWidget->addView(QUrl(QSL("falkon:restore")), Qz::NT_CleanSelectedTabAtTheEnd);
         }
         else if (mApp->afterLaunch() == MainApplication::SelectSession || mApp->afterLaunch() == MainApplication::RestoreSession) {
             addTab = m_tabWidget->count() <= 0;
@@ -328,7 +327,7 @@ void BrowserWindow::postLaunch()
     }
 
     mApp->plugins()->emitMainWindowCreated(this);
-    emit startingCompleted();
+    Q_EMIT startingCompleted();
 
     raise();
     activateWindow();
@@ -338,7 +337,7 @@ void BrowserWindow::postLaunch()
 void BrowserWindow::setupUi()
 {
     Settings settings;
-    settings.beginGroup("Browser-View-Settings");
+    settings.beginGroup(QSL("Browser-View-Settings"));
     const QByteArray windowGeometry = settings.value(QSL("WindowGeometry")).toByteArray();
 
     const QStringList keys = {
@@ -356,7 +355,7 @@ void BrowserWindow::setupUi()
     }
     settings.endGroup();
 
-    QWidget* widget = new QWidget(this);
+    auto* widget = new QWidget(this);
     widget->setCursor(Qt::ArrowCursor);
     setCentralWidget(widget);
 
@@ -364,7 +363,7 @@ void BrowserWindow::setupUi()
     m_mainLayout->setContentsMargins(0, 0, 0, 0);
     m_mainLayout->setSpacing(0);
     m_mainSplitter = new QSplitter(this);
-    m_mainSplitter->setObjectName("sidebar-splitter");
+    m_mainSplitter->setObjectName(QSL("sidebar-splitter"));
     m_tabWidget = new TabWidget(this);
     m_superMenu = new QMenu(this);
     m_navigationToolbar = new NavigationBar(this);
@@ -386,18 +385,18 @@ void BrowserWindow::setupUi()
     m_mainLayout->addWidget(m_mainSplitter);
 
     m_statusBar = new StatusBar(this);
-    m_statusBar->setObjectName("mainwindow-statusbar");
+    m_statusBar->setObjectName(QSL("mainwindow-statusbar"));
     m_statusBar->setCursor(Qt::ArrowCursor);
     setStatusBar(m_statusBar);
     m_progressBar = new ProgressBar(m_statusBar);
     m_ipLabel = new QLabel(this);
-    m_ipLabel->setObjectName("statusbar-ip-label");
+    m_ipLabel->setObjectName(QSL("statusbar-ip-label"));
     m_ipLabel->setToolTip(tr("IP Address of current page"));
 
     m_statusBar->addPermanentWidget(m_progressBar);
     m_statusBar->addPermanentWidget(m_ipLabel);
 
-    DownloadsButton *downloadsButton = new DownloadsButton(this);
+    auto *downloadsButton = new DownloadsButton(this);
     m_statusBar->addButton(downloadsButton);
     m_navigationToolbar->addToolButton(downloadsButton);
 
@@ -461,26 +460,26 @@ void BrowserWindow::setupMenu()
     m_mainMenu->initSuperMenu(m_superMenu);
 
     // Setup other shortcuts
-    QShortcut* reloadBypassCacheAction = new QShortcut(QKeySequence(QSL("Ctrl+F5")), this);
-    QShortcut* reloadBypassCacheAction2 = new QShortcut(QKeySequence(QSL("Ctrl+Shift+R")), this);
-    connect(reloadBypassCacheAction, SIGNAL(activated()), this, SLOT(reloadBypassCache()));
-    connect(reloadBypassCacheAction2, SIGNAL(activated()), this, SLOT(reloadBypassCache()));
+    auto* reloadBypassCacheAction = new QShortcut(QKeySequence(QSL("Ctrl+F5")), this);
+    auto* reloadBypassCacheAction2 = new QShortcut(QKeySequence(QSL("Ctrl+Shift+R")), this);
+    connect(reloadBypassCacheAction, &QShortcut::activated, this, &BrowserWindow::reloadBypassCache);
+    connect(reloadBypassCacheAction2, &QShortcut::activated, this, &BrowserWindow::reloadBypassCache);
 
-    QShortcut* closeTabAction = new QShortcut(QKeySequence(QSL("Ctrl+W")), this);
-    QShortcut* closeTabAction2 = new QShortcut(QKeySequence(QSL("Ctrl+F4")), this);
-    connect(closeTabAction, SIGNAL(activated()), this, SLOT(closeTab()));
-    connect(closeTabAction2, SIGNAL(activated()), this, SLOT(closeTab()));
+    auto* closeTabAction = new QShortcut(QKeySequence(QSL("Ctrl+W")), this);
+    auto* closeTabAction2 = new QShortcut(QKeySequence(QSL("Ctrl+F4")), this);
+    connect(closeTabAction, &QShortcut::activated, this, &BrowserWindow::closeTab);
+    connect(closeTabAction2, &QShortcut::activated, this, &BrowserWindow::closeTab);
 
-    QShortcut* reloadAction = new QShortcut(QKeySequence("Ctrl+R"), this);
-    connect(reloadAction, SIGNAL(activated()), this, SLOT(reload()));
+    auto* reloadAction = new QShortcut(QKeySequence(QSL("Ctrl+R")), this);
+    connect(reloadAction, &QShortcut::activated, this, &BrowserWindow::reload);
 
-    QShortcut* openLocationAction = new QShortcut(QKeySequence("Alt+D"), this);
-    connect(openLocationAction, SIGNAL(activated()), this, SLOT(openLocation()));
+    auto* openLocationAction = new QShortcut(QKeySequence(QSL("Alt+D")), this);
+    connect(openLocationAction, &QShortcut::activated, this, &BrowserWindow::openLocation);
 
-    QShortcut* inspectorAction = new QShortcut(QKeySequence(QSL("F12")), this);
-    connect(inspectorAction, SIGNAL(activated()), this, SLOT(toggleWebInspector()));
+    auto* inspectorAction = new QShortcut(QKeySequence(QSL("F12")), this);
+    connect(inspectorAction, &QShortcut::activated, this, &BrowserWindow::toggleWebInspector);
 
-    QShortcut* restoreClosedWindow = new QShortcut(QKeySequence(QSL("Ctrl+Shift+N")), this);
+    auto* restoreClosedWindow = new QShortcut(QKeySequence(QSL("Ctrl+Shift+N")), this);
     connect(restoreClosedWindow, &QShortcut::activated, mApp->closedWindowsManager(), &ClosedWindowsManager::restoreClosedWindow);
 }
 
@@ -500,10 +499,10 @@ void BrowserWindow::updateStartupFocus()
 QAction* BrowserWindow::createEncodingAction(const QString &codecName,
                                              const QString &activeCodecName, QMenu* menu)
 {
-    QAction* action = new QAction(codecName, menu);
+    auto* action = new QAction(codecName, menu);
     action->setData(codecName);
     action->setCheckable(true);
-    connect(action, SIGNAL(triggered()), this, SLOT(changeEncoding()));
+    connect(action, &QAction::triggered, this, &BrowserWindow::changeEncoding);
     if (activeCodecName.compare(codecName, Qt::CaseInsensitive) == 0) {
         action->setChecked(true);
     }
@@ -522,12 +521,12 @@ void BrowserWindow::createEncodingSubMenu(const QString &name, QStringList &code
         return collator.compare(a, b) < 0;
     });
 
-    QMenu* subMenu = new QMenu(name, menu);
+    auto* subMenu = new QMenu(name, menu);
     const QString activeCodecName = mApp->webSettings()->defaultTextEncoding();
 
-    QActionGroup *group = new QActionGroup(subMenu);
+    auto *group = new QActionGroup(subMenu);
 
-    foreach (const QString &codecName, codecNames) {
+    for (const QString &codecName : qAsConst(codecNames)) {
         QAction *act = createEncodingAction(codecName, activeCodecName, subMenu);
         group->addAction(act);
         subMenu->addAction(act);
@@ -574,35 +573,35 @@ void BrowserWindow::loadSettings()
     Settings settings;
 
     //Url settings
-    settings.beginGroup("Web-URL-Settings");
-    m_homepage = settings.value("homepage", "falkon:start").toUrl();
+    settings.beginGroup(QSL("Web-URL-Settings"));
+    m_homepage = settings.value(QSL("homepage"), QSL("falkon:start")).toUrl();
     settings.endGroup();
 
     //Browser Window settings
-    settings.beginGroup("Browser-View-Settings");
-    bool showStatusBar = settings.value("showStatusBar", false).toBool();
-    bool showBookmarksToolbar = settings.value("showBookmarksToolbar", false).toBool();
-    bool showNavigationToolbar = settings.value("showNavigationToolbar", true).toBool();
-    bool showMenuBar = settings.value("showMenubar", false).toBool();
+    settings.beginGroup(QSL("Browser-View-Settings"));
+    bool showStatusBar = settings.value(QSL("showStatusBar"), false).toBool();
+    bool showBookmarksToolbar = settings.value(QSL("showBookmarksToolbar"), false).toBool();
+    bool showNavigationToolbar = settings.value(QSL("showNavigationToolbar"), true).toBool();
+    bool showMenuBar = settings.value(QSL("showMenubar"), false).toBool();
 
     // Make sure both menubar and navigationbar are not hidden
     // Fixes #781
     if (!showNavigationToolbar) {
         showMenuBar = true;
-        settings.setValue("showMenubar", true);
+        settings.setValue(QSL("showMenubar"), true);
     }
 
     settings.endGroup();
 
-    settings.beginGroup("Shortcuts");
-    m_useTabNumberShortcuts = settings.value("useTabNumberShortcuts", true).toBool();
-    m_useSpeedDialNumberShortcuts = settings.value("useSpeedDialNumberShortcuts", true).toBool();
-    m_useSingleKeyShortcuts = settings.value("useSingleKeyShortcuts", false).toBool();
+    settings.beginGroup(QSL("Shortcuts"));
+    m_useTabNumberShortcuts = settings.value(QSL("useTabNumberShortcuts"), true).toBool();
+    m_useSpeedDialNumberShortcuts = settings.value(QSL("useSpeedDialNumberShortcuts"), true).toBool();
+    m_useSingleKeyShortcuts = settings.value(QSL("useSingleKeyShortcuts"), false).toBool();
     settings.endGroup();
 
-    settings.beginGroup("Web-Browser-Settings");
+    settings.beginGroup(QSL("Web-Browser-Settings"));
     QAction *quitAction = m_mainMenu->action(QSL("Standard/Quit"));
-    if (settings.value("closeAppWithCtrlQ", true).toBool()) {
+    if (settings.value(QSL("closeAppWithCtrlQ"), true).toBool()) {
         quitAction->setShortcut(QzTools::actionShortcut(QKeySequence::Quit, QKeySequence(QSL("Ctrl+Q"))));
     } else {
         quitAction->setShortcut(QKeySequence());
@@ -654,9 +653,9 @@ TabbedWebView* BrowserWindow::weView() const
 
 TabbedWebView* BrowserWindow::weView(int index) const
 {
-    WebTab* webTab = qobject_cast<WebTab*>(m_tabWidget->widget(index));
+    auto* webTab = qobject_cast<WebTab*>(m_tabWidget->widget(index));
     if (!webTab) {
-        return 0;
+        return nullptr;
     }
 
     return webTab->webView();
@@ -740,12 +739,12 @@ void BrowserWindow::setWindowTitle(const QString &t)
 
 void BrowserWindow::changeEncoding()
 {
-    if (QAction* action = qobject_cast<QAction*>(sender())) {
+    if (auto* action = qobject_cast<QAction*>(sender())) {
         const QString encoding = action->data().toString();
         mApp->webSettings()->setDefaultTextEncoding(encoding);
 
         Settings settings;
-        settings.setValue("Web-Browser-Settings/DefaultEncoding", encoding);
+        settings.setValue(QSL("Web-Browser-Settings/DefaultEncoding"), encoding);
 
         weView()->reload();
     }
@@ -788,7 +787,7 @@ void BrowserWindow::loadActionUrl(QObject* obj)
         obj = sender();
     }
 
-    if (QAction* action = qobject_cast<QAction*>(obj)) {
+    if (auto* action = qobject_cast<QAction*>(obj)) {
         loadAddress(action->data().toUrl());
     }
 }
@@ -799,7 +798,7 @@ void BrowserWindow::loadActionUrlInNewTab(QObject* obj)
         obj = sender();
     }
 
-    if (QAction* action = qobject_cast<QAction*>(obj)) {
+    if (auto* action = qobject_cast<QAction*>(obj)) {
         m_tabWidget->addView(action->data().toUrl(), Qz::NT_SelectedTabAtTheEnd);
     }
 }
@@ -811,7 +810,7 @@ void BrowserWindow::loadAddress(const QUrl &url)
         weView(index)->setFocus();
     } else {
         weView()->setFocus();
-        weView()->load(url);
+        weView()->load(LoadRequest(url));
     }
 }
 
@@ -868,7 +867,7 @@ void BrowserWindow::toggleShowMenubar()
 
     setUpdatesEnabled(true);
 
-    Settings().setValue("Browser-View-Settings/showMenubar", menuBar()->isVisible());
+    Settings().setValue(QSL("Browser-View-Settings/showMenubar"), menuBar()->isVisible());
 
     // Make sure we show Navigation Toolbar when Menu Bar is hidden
     if (!m_navigationToolbar->isVisible() && !menuBar()->isVisible()) {
@@ -884,7 +883,7 @@ void BrowserWindow::toggleShowStatusBar()
 
     setUpdatesEnabled(true);
 
-    Settings().setValue("Browser-View-Settings/showStatusBar", m_statusBar->isVisible());
+    Settings().setValue(QSL("Browser-View-Settings/showStatusBar"), m_statusBar->isVisible());
 
 }
 
@@ -896,8 +895,8 @@ void BrowserWindow::toggleShowBookmarksToolbar()
 
     setUpdatesEnabled(true);
 
-    Settings().setValue("Browser-View-Settings/showBookmarksToolbar", m_bookmarksToolbar->isVisible());
-    Settings().setValue("Browser-View-Settings/instantBookmarksToolbar", false);
+    Settings().setValue(QSL("Browser-View-Settings/showBookmarksToolbar"), m_bookmarksToolbar->isVisible());
+    Settings().setValue(QSL("Browser-View-Settings/instantBookmarksToolbar"), false);
 }
 
 void BrowserWindow::toggleShowNavigationToolbar()
@@ -908,7 +907,7 @@ void BrowserWindow::toggleShowNavigationToolbar()
 
     setUpdatesEnabled(true);
 
-    Settings().setValue("Browser-View-Settings/showNavigationToolbar", m_navigationToolbar->isVisible());
+    Settings().setValue(QSL("Browser-View-Settings/showNavigationToolbar"), m_navigationToolbar->isVisible());
 
 #ifndef Q_OS_MACOS
     // Make sure we show Menu Bar when Navigation Toolbar is hidden
@@ -1045,18 +1044,18 @@ void BrowserWindow::createToolbarsMenu(QMenu* menu)
     QAction* action;
 
 #ifndef Q_OS_MACOS
-    action = menu->addAction(tr("&Menu Bar"), this, SLOT(toggleShowMenubar()));
+    action = menu->addAction(tr("&Menu Bar"), this, &BrowserWindow::toggleShowMenubar);
     action->setCheckable(true);
     action->setChecked(menuBar()->isVisible());
 #endif
 
-    action = menu->addAction(tr("&Navigation Toolbar"), this, SLOT(toggleShowNavigationToolbar()));
+    action = menu->addAction(tr("&Navigation Toolbar"), this, &BrowserWindow::toggleShowNavigationToolbar);
     action->setCheckable(true);
     action->setChecked(m_navigationToolbar->isVisible());
 
-    action = menu->addAction(tr("&Bookmarks Toolbar"), this, SLOT(toggleShowBookmarksToolbar()));
+    action = menu->addAction(tr("&Bookmarks Toolbar"), this, &BrowserWindow::toggleShowBookmarksToolbar);
     action->setCheckable(true);
-    action->setChecked(Settings().value("Browser-View-Settings/showBookmarksToolbar").toBool());
+    action->setChecked(Settings().value(QSL("Browser-View-Settings/showBookmarksToolbar")).toBool());
 
     menu->addSeparator();
 
@@ -1084,7 +1083,8 @@ void BrowserWindow::createEncodingMenu(QMenu* menu)
     QStringList otherCodecs;
     QStringList allCodecs;
 
-    foreach (const int mib, QTextCodec::availableMibs()) {
+    const auto mibs = QTextCodec::availableMibs();
+    for (const int mib : mibs) {
         const QString codecName = QString::fromUtf8(QTextCodec::codecForMib(mib)->name());
 
         if (!allCodecs.contains(codecName))
@@ -1109,17 +1109,17 @@ void BrowserWindow::createEncodingMenu(QMenu* menu)
     if (!menu->isEmpty())
         menu->addSeparator();
 
-    createEncodingSubMenu("ISO", isoCodecs, menu);
-    createEncodingSubMenu("UTF", utfCodecs, menu);
-    createEncodingSubMenu("Windows", windowsCodecs, menu);
-    createEncodingSubMenu("Iscii", isciiCodecs, menu);
-    createEncodingSubMenu("IBM", ibmCodecs, menu);
+    createEncodingSubMenu(QSL("ISO"), isoCodecs, menu);
+    createEncodingSubMenu(QSL("UTF"), utfCodecs, menu);
+    createEncodingSubMenu(QSL("Windows"), windowsCodecs, menu);
+    createEncodingSubMenu(QSL("Iscii"), isciiCodecs, menu);
+    createEncodingSubMenu(QSL("IBM"), ibmCodecs, menu);
     createEncodingSubMenu(tr("Other"), otherCodecs, menu);
 }
 
 void BrowserWindow::removeActions(const QList<QAction *> &actions)
 {
-    foreach (QAction *action, actions) {
+    for (QAction *action : actions) {
         removeAction(action);
     }
 }
@@ -1142,18 +1142,23 @@ void BrowserWindow::webSearch()
 void BrowserWindow::searchOnPage()
 {
     if (weView() && weView()->webTab()) {
-        weView()->webTab()->showSearchToolBar();
+        const QString searchText = weView()->page()->selectedText();
+        if (!searchText.contains(QL1C('\n'))) {
+            weView()->webTab()->showSearchToolBar(searchText);
+        } else {
+            weView()->webTab()->showSearchToolBar();
+        }
     }
 }
 
 void BrowserWindow::openFile()
 {
-    const QString fileTypes = QString("%1(*.html *.htm *.shtml *.shtm *.xhtml);;"
+    const QString fileTypes = QSL("%1(*.html *.htm *.shtml *.shtm *.xhtml);;"
                                       "%2(*.png *.jpg *.jpeg *.bmp *.gif *.svg *.tiff);;"
                                       "%3(*.txt);;"
                                       "%4(*.*)").arg(tr("HTML files"), tr("Image files"), tr("Text files"), tr("All files"));
 
-    const QString filePath = QzTools::getOpenFileName("MainWindow-openFile", this, tr("Open file..."), QDir::homePath(), fileTypes);
+    const QString filePath = QzTools::getOpenFileName(QSL("MainWindow-openFile"), this, tr("Open file..."), QDir::homePath(), fileTypes);
 
     if (!filePath.isEmpty()) {
         loadAddress(QUrl::fromLocalFile(filePath));
@@ -1210,7 +1215,7 @@ void BrowserWindow::hideNavigationSlot()
 bool BrowserWindow::event(QEvent *event)
 {
     if (event->type() == QEvent::WindowStateChange) {
-        QWindowStateChangeEvent *e = static_cast<QWindowStateChangeEvent*>(event);
+        auto *e = static_cast<QWindowStateChangeEvent*>(event);
         if (!(e->oldState() & Qt::WindowFullScreen) && windowState() & Qt::WindowFullScreen) {
             // Enter fullscreen
             m_statusBarVisible = m_statusBar->isVisible();
@@ -1484,7 +1489,7 @@ void BrowserWindow::closeEvent(QCloseEvent* event)
     }
 
     Settings settings;
-    bool askOnClose = settings.value("Browser-Tabs-Settings/AskOnClosing", true).toBool();
+    bool askOnClose = settings.value(QSL("Browser-Tabs-Settings/AskOnClosing"), true).toBool();
 
     if ((mApp->afterLaunch() == MainApplication::SelectSession || mApp->afterLaunch() == MainApplication::RestoreSession) && mApp->windowCount() == 1) {
         askOnClose = false;
@@ -1506,11 +1511,11 @@ void BrowserWindow::closeEvent(QCloseEvent* event)
         }
 
         if (dialog.isChecked()) {
-            settings.setValue("Browser-Tabs-Settings/AskOnClosing", false);
+            settings.setValue(QSL("Browser-Tabs-Settings/AskOnClosing"), false);
         }
     }
 
-    emit aboutToClose();
+    Q_EMIT aboutToClose();
 
     saveSettings();
     mApp->closedWindowsManager()->saveWindow(this);
@@ -1542,8 +1547,8 @@ void BrowserWindow::saveSettings()
     }
 
     Settings settings;
-    settings.beginGroup("Browser-View-Settings");
-    settings.setValue("WindowGeometry", saveGeometry());
+    settings.beginGroup(QSL("Browser-View-Settings"));
+    settings.setValue(QSL("WindowGeometry"), saveGeometry());
 
     const auto state = saveUiState();
     for (auto it = state.constBegin(); it != state.constEnd(); ++it) {
