@@ -78,7 +78,7 @@ public:
     };
 
     explicit BrowserWindow(Qz::BrowserWindowType type, const QUrl &url = QUrl());
-    ~BrowserWindow();
+    ~BrowserWindow() override;
 
     void setStartTab(WebTab* tab);
     void setStartPage(WebPage* page);
@@ -130,6 +130,8 @@ Q_SIGNALS:
     void aboutToClose();
 
 public Q_SLOTS:
+    void addTab();
+
     void goHome();
     void goHomeInNewTab();
     void goBack();
@@ -159,10 +161,9 @@ public Q_SLOTS:
     void bookmarkPage();
     void bookmarkAllTabs();
     void loadAddress(const QUrl &url);
-    void showSource(WebView *view = Q_NULLPTR);
+    void showSource(WebView *view = nullptr);
 
 private Q_SLOTS:
-    void addTab();
     void openLocation();
     void openFile();
     void closeWindow();
@@ -179,11 +180,11 @@ private Q_SLOTS:
     void hideNavigationSlot();
 
 private:
-    bool event(QEvent* event);
-    void resizeEvent(QResizeEvent* event);
-    void keyPressEvent(QKeyEvent* event);
-    void keyReleaseEvent(QKeyEvent* event);
-    void closeEvent(QCloseEvent* event);
+    bool event(QEvent* event) override;
+    void resizeEvent(QResizeEvent* event) override;
+    void keyPressEvent(QKeyEvent* event) override;
+    void keyReleaseEvent(QKeyEvent* event) override;
+    void closeEvent(QCloseEvent* event) override;
 
     void setupUi();
     void setupMenu();
