@@ -34,7 +34,6 @@
 #include "checkboxdialog.h"
 #include "networkmanager.h"
 #include "profilemanager.h"
-#include "restoremanager.h"
 #include "browsinglibrary.h"
 #include "downloadmanager.h"
 #include "clearprivatedata.h"
@@ -69,9 +68,7 @@
 #include <QtWebEngineWidgetsVersion>
 #include <QtWebEngineCoreVersion>
 
-#if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(5, 13, 0)
 #include <QWebEngineNotification>
-#endif
 
 #ifdef Q_OS_WIN
 #include <QtWin>
@@ -296,14 +293,12 @@ MainApplication::MainApplication(int &argc, char** argv)
     m_webProfile = isPrivate() ? new QWebEngineProfile() : QWebEngineProfile::defaultProfile();
     connect(m_webProfile, &QWebEngineProfile::downloadRequested, this, &MainApplication::downloadRequested);
 
-#if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(5, 13, 0)
     m_webProfile->setNotificationPresenter([&] (std::unique_ptr<QWebEngineNotification> notification) {
         auto notifications = desktopNotifications();
         notifications->showNotification(
             QPixmap::fromImage(notification->icon()), notification->title(), notification->message()
         );
     });
-#endif
 
     m_networkManager = new NetworkManager(this);
 
@@ -449,7 +444,7 @@ BrowserWindow* MainApplication::createWindow(Qz::BrowserWindowType type, const Q
         type = Qz::BW_FirstAppWindow;
     }
 
-    BrowserWindow* window = new BrowserWindow(type, startUrl);
+    auto* window = new BrowserWindow(type, startUrl);
     connect(window, &QObject::destroyed, this, &MainApplication::windowDestroyed);
 
     m_windows.prepend(window);
@@ -514,7 +509,7 @@ void MainApplication::destroyRestoreManager()
 void MainApplication::reloadSettings()
 {
     loadSettings();
-    emit settingsReloaded();
+    Q_EMIT settingsReloaded();
 }
 
 QString MainApplication::styleName() const
@@ -686,7 +681,7 @@ void MainApplication::addNewTab(const QUrl &url)
 void MainApplication::startPrivateBrowsing(const QUrl &startUrl)
 {
     QUrl url = startUrl;
-    if (QAction* act = qobject_cast<QAction*>(sender())) {
+    if (auto* act = qobject_cast<QAction*>(sender())) {
         url = act->data().toUrl();
     }
 
@@ -728,7 +723,7 @@ void MainApplication::quitApplication()
     }
 
     for (BrowserWindow *window : qAsConst(m_windows)) {
-        emit window->aboutToClose();
+        Q_EMIT window->aboutToClose();
     }
 
     if (m_sessionManager && m_windows.count() > 0) {
@@ -867,7 +862,7 @@ void MainApplication::messageReceived(const QString &message)
             actWin = downloadManager();
         }
         else if (text == QLatin1String("ToggleFullScreen") && actWin) {
-            BrowserWindow* qz = static_cast<BrowserWindow*>(actWin);
+            auto* qz = static_cast<BrowserWindow*>(actWin);
             qz->toggleFullScreen();
         }
         else if (text.startsWith(QLatin1String("OpenUrlInCurrentTab"))) {
@@ -896,7 +891,7 @@ void MainApplication::messageReceived(const QString &message)
     actWin->activateWindow();
     actWin->setFocus();
 
-    BrowserWindow* win = qobject_cast<BrowserWindow*>(actWin);
+    auto* win = qobject_cast<BrowserWindow*>(actWin);
 
     if (win && !actUrl.isEmpty()) {
         win->loadAddress(actUrl);
@@ -914,12 +909,12 @@ void MainApplication::windowDestroyed(QObject* window)
 
 void MainApplication::onFocusChanged()
 {
-    BrowserWindow* activeBrowserWindow = qobject_cast<BrowserWindow*>(activeWindow());
+    auto* activeBrowserWindow = qobject_cast<BrowserWindow*>(activeWindow());
 
     if (activeBrowserWindow) {
         m_lastActiveWindow = activeBrowserWindow;
 
-        emit activeWindowChanged(m_lastActiveWindow);
+        Q_EMIT activeWindowChanged(m_lastActiveWindow);
     }
 }
 
@@ -963,25 +958,15 @@ void MainApplication::loadSettings()
     webSettings->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls, true);
     webSettings->setAttribute(QWebEngineSettings::FocusOnNavigationEnabled, false);
 
-#if QTWEBENGINEWIDGETS_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     webSettings->setAttribute(QWebEngineSettings::AllowWindowActivationFromJavaScript, settings.value(QSL("allowJavaScriptActivateWindow"), false).toBool());
-#endif
 
-#if QTWEBENGINEWIDGETS_VERSION >= QT_VERSION_CHECK(5, 11, 0)
     webSettings->setAttribute(QWebEngineSettings::JavascriptCanPaste, settings.value(QSL("allowJavaScriptPaste"), true).toBool());
     webSettings->setAttribute(QWebEngineSettings::PlaybackRequiresUserGesture, settings.value(QSL("DisableVideoAutoPlay"), false).toBool());
     webSettings->setAttribute(QWebEngineSettings::WebRTCPublicInterfacesOnly, settings.value(QSL("WebRTCPublicIpOnly"), true).toBool());
     webSettings->setUnknownUrlSchemePolicy(QWebEngineSettings::AllowAllUnknownUrlSchemes);
-#endif
-
-#if QTWEBENGINEWIDGETS_VERSION >= QT_VERSION_CHECK(5, 12, 0)
     webSettings->setAttribute(QWebEngineSettings::DnsPrefetchEnabled, settings.value(QSL("DNSPrefetch"), true).toBool());
-#endif
-
-#if QTWEBENGINEWIDGETS_VERSION >= QT_VERSION_CHECK(5, 13, 0)
     webSettings->setAttribute(QWebEngineSettings::PdfViewerEnabled, settings.value(QSL("intPDFViewer"), false).toBool());
     webSettings->setAttribute(QWebEngineSettings::ScreenCaptureEnabled, settings.value(QSL("screenCaptureEnabled"), false).toBool());
-#endif
 
     webSettings->setDefaultTextEncoding(settings.value(QSL("DefaultEncoding"), webSettings->defaultTextEncoding()).toString());
 
