@@ -107,9 +107,9 @@ void BookmarksManager::createContextMenu(const QPoint &pos)
     QAction* actNewPrivateWindow = menu.addAction(IconProvider::privateBrowsingIcon(), tr("Open in new private window"));
 
     menu.addSeparator();
-    menu.addAction(tr("New Bookmark"), this, SLOT(addBookmark()));
-    menu.addAction(tr("New Folder"), this, &BookmarksManager::addFolder);
-    menu.addAction(tr("New Separator"), this, &BookmarksManager::addSeparator);
+    QAction *actNewBookmark = menu.addAction(tr("New Bookmark"), this, SLOT(addBookmark()));
+    QAction *actNewFolder = menu.addAction(tr("New Folder"), this, &BookmarksManager::addFolder);
+    QAction *actNewSeparator = menu.addAction(tr("New Separator"), this, &BookmarksManager::addSeparator);
     menu.addSeparator();
     QAction* actDelete = menu.addAction(QIcon::fromTheme(QSL("edit-delete")), tr("Delete"));
 
@@ -119,9 +119,9 @@ void BookmarksManager::createContextMenu(const QPoint &pos)
     connect(actDelete, &QAction::triggered, this, &BookmarksManager::deleteBookmarks);
 
     bool canBeDeleted = false;
-    QList<BookmarkItem*> items = ui->tree->selectedBookmarks();
+    const QList<BookmarkItem*> items = ui->tree->selectedBookmarks();
 
-    foreach (BookmarkItem* item, items) {
+    for (BookmarkItem* item : items) {
         if (m_bookmarks->canBeModified(item)) {
             canBeDeleted = true;
             break;
@@ -138,6 +138,12 @@ void BookmarksManager::createContextMenu(const QPoint &pos)
         actNewPrivateWindow->setDisabled(true);
     }
 
+    if (!m_selectedBookmark) {
+        actNewBookmark->setDisabled(true);
+        actNewFolder->setDisabled(true);
+        actNewSeparator->setDisabled(true);
+    }
+
     menu.exec(pos);
 }
 
@@ -167,7 +173,7 @@ void BookmarksManager::openBookmarkInNewPrivateWindow(BookmarkItem* item)
 
 void BookmarksManager::addBookmark()
 {
-    BookmarkItem* item = new BookmarkItem(BookmarkItem::Url);
+    auto* item = new BookmarkItem(BookmarkItem::Url);
     item->setTitle(tr("New Bookmark"));
     item->setUrl(QUrl(QSL("http://")));
     addBookmark(item);
@@ -175,22 +181,22 @@ void BookmarksManager::addBookmark()
 
 void BookmarksManager::addFolder()
 {
-    BookmarkItem* item = new BookmarkItem(BookmarkItem::Folder);
+    auto* item = new BookmarkItem(BookmarkItem::Folder);
     item->setTitle(tr("New Folder"));
     addBookmark(item);
 }
 
 void BookmarksManager::addSeparator()
 {
-    BookmarkItem* item = new BookmarkItem(BookmarkItem::Separator);
+    auto* item = new BookmarkItem(BookmarkItem::Separator);
     addBookmark(item);
 }
 
 void BookmarksManager::deleteBookmarks()
 {
-    QList<BookmarkItem*> items = ui->tree->selectedBookmarks();
+    const QList<BookmarkItem*> items = ui->tree->selectedBookmarks();
 
-    foreach (BookmarkItem* item, items) {
+    for (BookmarkItem* item : items) {
         if (m_bookmarks->canBeModified(item)) {
             m_bookmarks->removeBookmark(item);
         }
@@ -261,7 +267,7 @@ void BookmarksManager::updateEditBox(BookmarkItem* item)
     ui->keyword->setVisible(showAddressAndKeyword);
 
     // Without removing widgets from layout, there is unwanted extra spacing
-    QFormLayout* l = static_cast<QFormLayout*>(ui->editBox->layout());
+    auto* l = static_cast<QFormLayout*>(ui->editBox->layout());
 
     if (showAddressAndKeyword) {
         // Show Address + Keyword
