@@ -51,7 +51,7 @@ public:
         bool askWhatToDo;
         bool forceChoosingPath;
 
-        DownloadInfo(WebPage* p = 0) {
+        DownloadInfo(WebPage* p = nullptr) {
             page = p;
             suggestedFileName = QString();
             askWhatToDo = true;
@@ -59,8 +59,8 @@ public:
         }
     };
 
-    explicit DownloadManager(QWidget* parent = 0);
-    ~DownloadManager();
+    explicit DownloadManager(QWidget* parent = nullptr);
+    ~DownloadManager() override;
 
     void loadSettings();
 
@@ -95,7 +95,7 @@ private:
     void resizeEvent(QResizeEvent* e) override;
     void keyPressEvent(QKeyEvent* e) override;
 
-    void closeDownloadTab(const QUrl &url) const;
+    void closeDownloadTab(QWebEngineDownloadItem *item) const;
     QWinTaskbarButton *taskbarButton();
 
     Ui::DownloadManager* ui;
