@@ -79,10 +79,10 @@ void LocationCompleter::complete(const QString &string)
     // Eg. popup was not closed yet this completion session
     m_popupClosed = false;
 
-    emit cancelRefreshJob();
+    Q_EMIT cancelRefreshJob();
 
-    LocationCompleterRefreshJob* job = new LocationCompleterRefreshJob(trimmedStr);
-    connect(job, SIGNAL(finished()), this, SLOT(refreshJobFinished()));
+    auto* job = new LocationCompleterRefreshJob(trimmedStr);
+    connect(job, &LocationCompleterRefreshJob::finished, this, &LocationCompleter::refreshJobFinished);
     connect(this, SIGNAL(cancelRefreshJob()), job, SLOT(jobCancelled()));
 
     if (qzSettings->searchFromAddressBar && qzSettings->showABSearchSuggestions && trimmedStr.length() >= 2) {
@@ -107,7 +107,7 @@ void LocationCompleter::complete(const QString &string)
             s_model->setData(index, trimmedStr, LocationCompleterModel::UrlRole);
             s_model->setData(index, m_locationBar->text(), LocationCompleterModel::SearchStringRole);
         } else {
-            QStandardItem *item = new QStandardItem();
+            auto *item = new QStandardItem();
             item->setText(trimmedStr);
             item->setData(trimmedStr, LocationCompleterModel::UrlRole);
             item->setData(m_locationBar->text(), LocationCompleterModel::SearchStringRole);
@@ -132,7 +132,7 @@ void LocationCompleter::showMostVisited()
 
 void LocationCompleter::refreshJobFinished()
 {
-    LocationCompleterRefreshJob* job = qobject_cast<LocationCompleterRefreshJob*>(sender());
+    auto* job = qobject_cast<LocationCompleterRefreshJob*>(sender());
     Q_ASSERT(job);
 
     // Don't show results of older jobs
@@ -151,7 +151,7 @@ void LocationCompleter::refreshJobFinished()
         }
 
         if (qzSettings->useInlineCompletion) {
-            emit showDomainCompletion(job->domainCompletion());
+            Q_EMIT showDomainCompletion(job->domainCompletion());
         }
 
         s_model->setData(s_model->index(0, 0), m_locationBar->text(), LocationCompleterModel::SearchStringRole);
@@ -165,16 +165,16 @@ void LocationCompleter::slotPopupClosed()
     m_popupClosed = true;
     m_oldSuggestions.clear();
 
-    disconnect(s_view, SIGNAL(closed()), this, SLOT(slotPopupClosed()));
-    disconnect(s_view, SIGNAL(indexActivated(QModelIndex)), this, SLOT(indexActivated(QModelIndex)));
-    disconnect(s_view, SIGNAL(indexCtrlActivated(QModelIndex)), this, SLOT(indexCtrlActivated(QModelIndex)));
-    disconnect(s_view, SIGNAL(indexShiftActivated(QModelIndex)), this, SLOT(indexShiftActivated(QModelIndex)));
-    disconnect(s_view, SIGNAL(indexDeleteRequested(QModelIndex)), this, SLOT(indexDeleteRequested(QModelIndex)));
+    disconnect(s_view, &LocationCompleterView::closed, this, &LocationCompleter::slotPopupClosed);
+    disconnect(s_view, &LocationCompleterView::indexActivated, this, &LocationCompleter::indexActivated);
+    disconnect(s_view, &LocationCompleterView::indexCtrlActivated, this, &LocationCompleter::indexCtrlActivated);
+    disconnect(s_view, &LocationCompleterView::indexShiftActivated, this, &LocationCompleter::indexShiftActivated);
+    disconnect(s_view, &LocationCompleterView::indexDeleteRequested, this, &LocationCompleter::indexDeleteRequested);
     disconnect(s_view, &LocationCompleterView::loadRequested, this, &LocationCompleter::loadRequested);
     disconnect(s_view, &LocationCompleterView::searchEnginesDialogRequested, this, &LocationCompleter::openSearchEnginesDialog);
-    disconnect(s_view->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)), this, SLOT(currentChanged(QModelIndex)));
+    disconnect(s_view->selectionModel(), &QItemSelectionModel::currentChanged, this, &LocationCompleter::currentChanged);
 
-    emit popupClosed();
+    Q_EMIT popupClosed();
 }
 
 void LocationCompleter::addSuggestions(const QStringList &suggestions)
@@ -190,7 +190,7 @@ void LocationCompleter::addSuggestions(const QStringList &suggestions)
     // Add new suggestions
     QList<QStandardItem*> items;
     for (const QString &suggestion : suggestions) {
-        QStandardItem* item = new QStandardItem();
+        auto* item = new QStandardItem();
         item->setText(suggestion);
         item->setData(suggestion, LocationCompleterModel::TitleRole);
         item->setData(suggestion, LocationCompleterModel::UrlRole);
@@ -229,7 +229,7 @@ void LocationCompleter::currentChanged(const QModelIndex &index)
         completion = originalText;
     }
 
-    emit showCompletion(completion, completeDomain);
+    Q_EMIT showCompletion(completion, completeDomain);
 }
 
 void LocationCompleter::indexActivated(const QModelIndex &index)
@@ -239,7 +239,7 @@ void LocationCompleter::indexActivated(const QModelIndex &index)
     closePopup();
 
     // Clear locationbar
-    emit clearCompletion();
+    Q_EMIT clearCompletion();
 
     bool ok;
     const int tabPos = index.data(LocationCompleterModel::TabPositionTabRole).toInt(&ok);
@@ -263,7 +263,7 @@ void LocationCompleter::indexCtrlActivated(const QModelIndex &index)
     closePopup();
 
     // Clear locationbar
-    emit clearCompletion();
+    Q_EMIT clearCompletion();
 
     // Load request in new tab
     m_window->tabWidget()->addView(createLoadRequest(index), Qz::NT_CleanSelectedTab);
@@ -276,7 +276,7 @@ void LocationCompleter::indexShiftActivated(const QModelIndex &index)
     closePopup();
 
     // Clear locationbar
-    emit clearCompletion();
+    Q_EMIT clearCompletion();
 
     // Load request
     if (index.data(LocationCompleterModel::VisitSearchItemRole).toBool()) {
@@ -367,18 +367,18 @@ void LocationCompleter::loadRequest(const LoadRequest &request)
     closePopup();
 
     // Show url in locationbar
-    emit showCompletion(request.url().toString(), false);
+    Q_EMIT showCompletion(request.url().toString(), false);
 
     // Load request
-    emit loadRequested(request);
+    Q_EMIT loadRequested(request);
 }
 
 void LocationCompleter::openSearchEnginesDialog()
 {
     // Clear locationbar
-    emit clearCompletion();
+    Q_EMIT clearCompletion();
 
-    SearchEnginesDialog *dialog = new SearchEnginesDialog(m_window);
+    auto *dialog = new SearchEnginesDialog(m_window);
     dialog->open();
 }
 
@@ -404,14 +404,14 @@ void LocationCompleter::showPopup()
     s_view->setFocusProxy(m_locationBar);
     s_view->setCurrentIndex(QModelIndex());
 
-    connect(s_view, SIGNAL(closed()), this, SLOT(slotPopupClosed()));
-    connect(s_view, SIGNAL(indexActivated(QModelIndex)), this, SLOT(indexActivated(QModelIndex)));
-    connect(s_view, SIGNAL(indexCtrlActivated(QModelIndex)), this, SLOT(indexCtrlActivated(QModelIndex)));
-    connect(s_view, SIGNAL(indexShiftActivated(QModelIndex)), this, SLOT(indexShiftActivated(QModelIndex)));
-    connect(s_view, SIGNAL(indexDeleteRequested(QModelIndex)), this, SLOT(indexDeleteRequested(QModelIndex)));
+    connect(s_view, &LocationCompleterView::closed, this, &LocationCompleter::slotPopupClosed);
+    connect(s_view, &LocationCompleterView::indexActivated, this, &LocationCompleter::indexActivated);
+    connect(s_view, &LocationCompleterView::indexCtrlActivated, this, &LocationCompleter::indexCtrlActivated);
+    connect(s_view, &LocationCompleterView::indexShiftActivated, this, &LocationCompleter::indexShiftActivated);
+    connect(s_view, &LocationCompleterView::indexDeleteRequested, this, &LocationCompleter::indexDeleteRequested);
     connect(s_view, &LocationCompleterView::loadRequested, this, &LocationCompleter::loadRequested);
     connect(s_view, &LocationCompleterView::searchEnginesDialogRequested, this, &LocationCompleter::openSearchEnginesDialog);
-    connect(s_view->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)), this, SLOT(currentChanged(QModelIndex)));
+    connect(s_view->selectionModel(), &QItemSelectionModel::currentChanged, this, &LocationCompleter::currentChanged);
 
     s_view->createWinId();
     s_view->windowHandle()->setTransientParent(m_window->windowHandle());
