@@ -27,6 +27,7 @@
 #include "networkurlinterceptor.h"
 #include "schemehandlers/falkonschemehandler.h"
 #include "schemehandlers/extensionschemehandler.h"
+#include "webpage.h"
 
 #include <QLabel>
 #include <QDialog>
@@ -38,19 +39,24 @@
 #include <QNetworkReply>
 #include <QNetworkProxy>
 #include <QWebEngineProfile>
-#include <QWebEngineCertificateError>
+#include <QtWebEngineWidgetsVersion>
+
+#include <QWebEngineUrlScheme>
 
 NetworkManager::NetworkManager(QObject *parent)
     : QNetworkAccessManager(parent)
 {
     // Create scheme handlers
-    mApp->webProfile()->installUrlSchemeHandler(QByteArrayLiteral("falkon"), new FalkonSchemeHandler());
     m_extensionScheme = new ExtensionSchemeManager();
+
+    mApp->webProfile()->installUrlSchemeHandler(QByteArrayLiteral("falkon"), new FalkonSchemeHandler());
     mApp->webProfile()->installUrlSchemeHandler(QByteArrayLiteral("extension"), m_extensionScheme);
+    WebPage::addSupportedScheme(QSL("falkon"));
+    WebPage::addSupportedScheme(QSL("extension"));
 
     // Create url interceptor
     m_urlInterceptor = new NetworkUrlInterceptor(this);
-    mApp->webProfile()->setRequestInterceptor(m_urlInterceptor);
+    mApp->webProfile()->setUrlRequestInterceptor(m_urlInterceptor);
 
     // Create cookie jar
     mApp->cookieJar();
@@ -68,6 +74,10 @@ bool NetworkManager::certificateError(const QWebEngineCertificateError &error, Q
 {
     const QString &host = error.url().host();
 
+    if (m_rejectedSslErrors.contains(host) && m_rejectedSslErrors.value(host) == error.error()) {
+        return false;
+    }
+
     if (m_ignoredSslErrors.contains(host) && m_ignoredSslErrors.value(host) == error.error())
         return true;
 
@@ -85,10 +95,13 @@ bool NetworkManager::certificateError(const QWebEngineCertificateError &error, Q
     case SslErrorDialog::Yes:
         // TODO: Permanent exceptions
     case SslErrorDialog::OnlyForThisSession:
-        m_ignoredSslErrors[error.url().host()] = error.error();
+        m_ignoredSslErrors[host] = error.error();
         return true;
 
-    case SslErrorDialog::No:
+    case SslErrorDialog::NoForThisSession:
+        m_rejectedSslErrors[host] = error.error();
+        return false;
+
     default:
         return false;
     }
@@ -96,28 +109,28 @@ bool NetworkManager::certificateError(const QWebEngineCertificateError &error, Q
 
 void NetworkManager::authentication(const QUrl &url, QAuthenticator *auth, QWidget *parent)
 {
-    QDialog* dialog = new QDialog(parent);
-    dialog->setWindowTitle(tr("Authorisation required"));
+    auto* dialog = new QDialog(parent);
+    dialog->setWindowTitle(tr("Authorization required"));
 
-    QFormLayout* formLa = new QFormLayout(dialog);
+    auto* formLa = new QFormLayout(dialog);
 
-    QLabel* label = new QLabel(dialog);
-    QLabel* userLab = new QLabel(dialog);
-    QLabel* passLab = new QLabel(dialog);
+    auto* label = new QLabel(dialog);
+    auto* userLab = new QLabel(dialog);
+    auto* passLab = new QLabel(dialog);
     userLab->setText(tr("Username: "));
     passLab->setText(tr("Password: "));
 
-    QLineEdit* user = new QLineEdit(dialog);
-    QLineEdit* pass = new QLineEdit(dialog);
+    auto* user = new QLineEdit(dialog);
+    auto* pass = new QLineEdit(dialog);
     pass->setEchoMode(QLineEdit::Password);
-    QCheckBox* save = new QCheckBox(dialog);
+    auto* save = new QCheckBox(dialog);
     save->setText(tr("Save username and password for this site"));
 
-    QDialogButtonBox* box = new QDialogButtonBox(dialog);
+    auto* box = new QDialogButtonBox(dialog);
     box->addButton(QDialogButtonBox::Ok);
     box->addButton(QDialogButtonBox::Cancel);
-    connect(box, SIGNAL(rejected()), dialog, SLOT(reject()));
-    connect(box, SIGNAL(accepted()), dialog, SLOT(accept()));
+    connect(box, &QDialogButtonBox::rejected, dialog, &QDialog::reject);
+    connect(box, &QDialogButtonBox::accepted, dialog, &QDialog::accept);
 
     label->setText(tr("A username and password are being requested by %1. "
                       "The site says: \"%2\"").arg(url.host(), auth->realm().toHtmlEscaped()));
@@ -182,26 +195,26 @@ void NetworkManager::proxyAuthentication(const QString &proxyHost, QAuthenticato
         return;
     }
 
-    QDialog* dialog = new QDialog(parent);
-    dialog->setWindowTitle(tr("Proxy authorisation required"));
+    auto* dialog = new QDialog(parent);
+    dialog->setWindowTitle(tr("Proxy authorization required"));
 
-    QFormLayout* formLa = new QFormLayout(dialog);
+    auto* formLa = new QFormLayout(dialog);
 
-    QLabel* label = new QLabel(dialog);
-    QLabel* userLab = new QLabel(dialog);
-    QLabel* passLab = new QLabel(dialog);
+    auto* label = new QLabel(dialog);
+    auto* userLab = new QLabel(dialog);
+    auto* passLab = new QLabel(dialog);
     userLab->setText(tr("Username: "));
     passLab->setText(tr("Password: "));
 
-    QLineEdit* user = new QLineEdit(dialog);
-    QLineEdit* pass = new QLineEdit(dialog);
+    auto* user = new QLineEdit(dialog);
+    auto* pass = new QLineEdit(dialog);
     pass->setEchoMode(QLineEdit::Password);
 
-    QDialogButtonBox* box = new QDialogButtonBox(dialog);
+    auto* box = new QDialogButtonBox(dialog);
     box->addButton(QDialogButtonBox::Ok);
     box->addButton(QDialogButtonBox::Cancel);
-    connect(box, SIGNAL(rejected()), dialog, SLOT(reject()));
-    connect(box, SIGNAL(accepted()), dialog, SLOT(accept()));
+    connect(box, &QDialogButtonBox::rejected, dialog, &QDialog::reject);
+    connect(box, &QDialogButtonBox::accepted, dialog, &QDialog::accept);
 
     label->setText(tr("A username and password are being requested by proxy %1. ").arg(proxyHost));
     formLa->addRow(label);
@@ -279,7 +292,20 @@ void NetworkManager::loadSettings()
 
 void NetworkManager::shutdown()
 {
-    mApp->webProfile()->setRequestInterceptor(nullptr);
+    mApp->webProfile()->setUrlRequestInterceptor(nullptr);
+}
+
+// static
+void NetworkManager::registerSchemes()
+{
+    QWebEngineUrlScheme falkonScheme("falkon");
+    falkonScheme.setFlags(QWebEngineUrlScheme::SecureScheme | QWebEngineUrlScheme::ContentSecurityPolicyIgnored);
+    falkonScheme.setSyntax(QWebEngineUrlScheme::Syntax::Path);
+    QWebEngineUrlScheme::registerScheme(falkonScheme);
+    QWebEngineUrlScheme extensionScheme("extension");
+    extensionScheme.setFlags(QWebEngineUrlScheme::SecureScheme | QWebEngineUrlScheme::ContentSecurityPolicyIgnored);
+    extensionScheme.setSyntax(QWebEngineUrlScheme::Syntax::Path);
+    QWebEngineUrlScheme::registerScheme(extensionScheme);
 }
 
 QNetworkReply *NetworkManager::createRequest(QNetworkAccessManager::Operation op, const QNetworkRequest &request, QIODevice *outgoingData)
