@@ -43,7 +43,7 @@ SearchEnginesDialog::SearchEnginesDialog(QWidget* parent)
     connect(ui->treeWidget, &QTreeWidget::itemDoubleClicked, this, &SearchEnginesDialog::editEngine);
 
     ui->treeWidget->setItemDelegate(new RemoveItemFocusDelegate(ui->treeWidget));
-    ui->treeWidget->sortByColumn(-1);
+    ui->treeWidget->sortByColumn(-1, Qt::AscendingOrder);
     reloadEngines();
 }
 
@@ -67,7 +67,7 @@ void SearchEnginesDialog::addEngine()
         return;
     }
 
-    QTreeWidgetItem* item = new QTreeWidgetItem();
+    auto* item = new QTreeWidgetItem();
     setEngine(item, engine);
 
     changeItemToDefault(item, false);
@@ -221,8 +221,9 @@ void SearchEnginesDialog::reloadEngines()
     ui->treeWidget->clear();
     const SearchEngine defaultEngine = mApp->searchEnginesManager()->defaultEngine();
 
-    foreach (const SearchEngine &en, m_manager->allEngines()) {
-        QTreeWidgetItem* item = new QTreeWidgetItem();
+    const auto engines = m_manager->allEngines();
+    for (const SearchEngine &en : engines) {
+        auto* item = new QTreeWidgetItem();
         setEngine(item, en);
         changeItemToDefault(item, en == defaultEngine);
         item->setIcon(0, en.icon);
