@@ -55,8 +55,8 @@ QStringList AcceptLanguage::defaultLanguage()
 
 QByteArray AcceptLanguage::generateHeader(const QStringList &langs)
 {
-    if (langs.count() == 0) {
-        return QByteArray();
+    if (langs.isEmpty()) {
+        return {};
     }
 
     QByteArray header;
@@ -87,10 +87,10 @@ AcceptLanguage::AcceptLanguage(QWidget* parent)
 
     Settings settings;
     settings.beginGroup("Language");
-    QStringList langs = settings.value("acceptLanguage", defaultLanguage()).toStringList();
+    const QStringList langs = settings.value("acceptLanguage", defaultLanguage()).toStringList();
     settings.endGroup();
 
-    foreach (const QString &code, langs) {
+    for (const QString &code : langs) {
         QString code_ = code;
         QLocale loc = QLocale(code_.replace(QLatin1Char('-'), QLatin1Char('_')));
         QString label;
@@ -126,7 +126,7 @@ QStringList AcceptLanguage::expand(const QLocale::Language &language)
             languageString = QString(QLatin1String("%1/%2 [%3]"))
                              .arg(QLocale::languageToString(language))
                              .arg(QLocale::countryToString(countries.at(j)))
-                             .arg(QLocale(language, countries.at(j)).name().split(QLatin1Char('_')).join(QLatin1String("-")).toLower());
+                             .arg(QLocale(language, countries.at(j)).name().split(QLatin1Char('_')).join(QLatin1Char('-')).toLower());
 
         }
         if (!allLanguages.contains(languageString)) {
