@@ -38,6 +38,7 @@ PluginsManager::PluginsManager(QWidget* parent)
     ui->setupUi(this);
     ui->list->setLayoutDirection(Qt::LeftToRight);
     ui->butSettings->setIcon(IconProvider::settingsIcon());
+    ui->butRemove->setIcon(QIcon::fromTheme(QSL("edit-delete")));
 
     //Application Extensions
     Settings settings;
@@ -48,8 +49,11 @@ PluginsManager::PluginsManager(QWidget* parent)
     ui->list->setEnabled(appPluginsEnabled);
 
     connect(ui->butSettings, &QAbstractButton::clicked, this, &PluginsManager::settingsClicked);
+    connect(ui->butRemove, &QAbstractButton::clicked, this, &PluginsManager::removeClicked);
     connect(ui->list, &QListWidget::currentItemChanged, this, &PluginsManager::currentChanged);
     connect(ui->list, &QListWidget::itemChanged, this, &PluginsManager::itemChanged);
+    connect(ui->search, &QLineEdit::textChanged, this, &PluginsManager::addFilter);
+    connect(mApp->plugins(), &Plugins::availablePluginsChanged, this, &PluginsManager::refresh);
 
     ui->list->setItemDelegate(new PluginListDelegate(ui->list));
 }
@@ -86,23 +90,29 @@ void PluginsManager::save()
 
 void PluginsManager::refresh()
 {
+    if (m_blockRefresh) {
+        return;
+    }
+
+    const int oldCurrentRow = ui->list->currentRow();
+
     ui->list->clear();
     ui->butSettings->setEnabled(false);
     disconnect(ui->list, &QListWidget::itemChanged, this, &PluginsManager::itemChanged);
 
-    const QList<Plugins::Plugin> &allPlugins = mApp->plugins()->getAvailablePlugins();
+    const QList<Plugins::Plugin> &allPlugins = mApp->plugins()->availablePlugins();
 
-    foreach (const Plugins::Plugin &plugin, allPlugins) {
+    for (const Plugins::Plugin &plugin : allPlugins) {
         PluginSpec spec = plugin.pluginSpec;
 
-        QListWidgetItem* item = new QListWidgetItem(ui->list);
+        auto* item = new QListWidgetItem(ui->list);
         QIcon icon = QIcon(spec.icon);
         if (icon.isNull()) {
             icon = QIcon(QSL(":/icons/preferences/extensions.svg"));
         }
         item->setIcon(icon);
 
-        QString pluginInfo = QString("<b>%1</b> %2<br/><i>%3</i><br/>").arg(spec.name, spec.version, spec.author.toHtmlEscaped());
+        const QString pluginInfo = QStringLiteral("<b>%1</b> %2<br/><i>%3</i><br/>").arg(spec.name, spec.version, spec.author.toHtmlEscaped());
         item->setToolTip(pluginInfo);
 
         item->setText(spec.name);
@@ -119,6 +129,11 @@ void PluginsManager::refresh()
 
     sortItems();
 
+    if (oldCurrentRow >= 0) {
+        ui->list->setCurrentRow(qMax(0, oldCurrentRow - 1));
+        ui->list->setFocus();
+    }
+
     connect(ui->list, &QListWidget::itemChanged, this, &PluginsManager::itemChanged);
 }
 
@@ -153,13 +168,8 @@ void PluginsManager::currentChanged(QListWidgetItem* item)
     }
 
     const Plugins::Plugin plugin = item->data(Qt::UserRole + 10).value<Plugins::Plugin>();
-    bool showSettings = plugin.pluginSpec.hasSettings;
-
-    if (!plugin.isLoaded()) {
-        showSettings = false;
-    }
-
-    ui->butSettings->setEnabled(showSettings);
+    ui->butSettings->setEnabled(plugin.isLoaded() && plugin.pluginSpec.hasSettings);
+    ui->butRemove->setEnabled(plugin.isRemovable());
 }
 
 void PluginsManager::itemChanged(QListWidgetItem* item)
@@ -170,6 +180,8 @@ void PluginsManager::itemChanged(QListWidgetItem* item)
 
     Plugins::Plugin plugin = item->data(Qt::UserRole + 10).value<Plugins::Plugin>();
 
+    m_blockRefresh = true;
+
     if (item->checkState() == Qt::Checked) {
         mApp->plugins()->loadPlugin(&plugin);
     }
@@ -177,6 +189,8 @@ void PluginsManager::itemChanged(QListWidgetItem* item)
         mApp->plugins()->unloadPlugin(&plugin);
     }
 
+    m_blockRefresh = false;
+
     disconnect(ui->list, &QListWidget::itemChanged, this, &PluginsManager::itemChanged);
 
     if (item->checkState() == Qt::Checked && !plugin.isLoaded()) {
@@ -188,7 +202,6 @@ void PluginsManager::itemChanged(QListWidgetItem* item)
 
     connect(ui->list, &QListWidget::itemChanged, this, &PluginsManager::itemChanged);
 
-
     currentChanged(ui->list->currentItem());
 }
 
@@ -212,6 +225,38 @@ void PluginsManager::settingsClicked()
     }
 }
 
+void PluginsManager::removeClicked()
+{
+    QListWidgetItem* item = ui->list->currentItem();
+    if (!item) {
+        return;
+    }
+
+    Plugins::Plugin plugin = item->data(Qt::UserRole + 10).value<Plugins::Plugin>();
+
+    const auto button = QMessageBox::warning(this, tr("Confirmation"),
+                                             tr("Are you sure you want to remove '%1'?").arg(plugin.pluginSpec.name),
+                                             QMessageBox::Yes | QMessageBox::No);
+    if (button != QMessageBox::Yes) {
+        return;
+    }
+
+    mApp->plugins()->removePlugin(&plugin);
+}
+
+void PluginsManager::addFilter(const QString& filter) {
+    for (int i = 0; i < ui->list->count(); ++i) {
+        const QString& pluginName = ui->list->item(i)->text();
+
+        if (pluginName.contains(filter,Qt::CaseInsensitive) || !filter.size()) {
+            ui->list->item(i)->setHidden(false);
+        }
+        else {
+            ui->list->item(i)->setHidden(true);
+        }
+    }
+}
+
 PluginsManager::~PluginsManager()
 {
     delete ui;
