@@ -36,7 +36,7 @@ TabIcon::TabIcon(QWidget* parent)
 
     m_updateTimer = new QTimer(this);
     m_updateTimer->setInterval(data()->animationInterval);
-    connect(m_updateTimer, SIGNAL(timeout()), this, SLOT(updateAnimationFrame()));
+    connect(m_updateTimer, &QTimer::timeout, this, &TabIcon::updateAnimationFrame);
 
     m_hideTimer = new QTimer(this);
     m_hideTimer->setInterval(250);
@@ -49,8 +49,8 @@ void TabIcon::setWebTab(WebTab* tab)
 {
     m_tab = tab;
 
-    connect(m_tab->webView(), SIGNAL(loadStarted()), this, SLOT(showLoadingAnimation()));
-    connect(m_tab->webView(), SIGNAL(loadFinished(bool)), this, SLOT(hideLoadingAnimation()));
+    connect(m_tab->webView(), &QWebEngineView::loadStarted, this, &TabIcon::showLoadingAnimation);
+    connect(m_tab->webView(), &QWebEngineView::loadFinished, this, &TabIcon::hideLoadingAnimation);
     connect(m_tab->webView(), &WebView::iconChanged, this, &TabIcon::updateIcon);
     connect(m_tab->webView(), &WebView::backgroundActivityChanged, this, [this]() { update(); });
 
@@ -133,7 +133,7 @@ void TabIcon::show()
     }
 
     setFixedSize(16, qMax(minimumHeight(), 16));
-    emit resized();
+    Q_EMIT resized();
     QWidget::show();
 }
 
@@ -148,7 +148,7 @@ void TabIcon::hide()
     }
 
     setFixedSize(1, qMax(minimumHeight(), 16));
-    emit resized();
+    Q_EMIT resized();
     QWidget::hide();
 }
 
@@ -163,7 +163,7 @@ bool TabIcon::shouldBeVisible() const
 bool TabIcon::event(QEvent *event)
 {
     if (event->type() == QEvent::ToolTip) {
-        QHelpEvent *e = static_cast<QHelpEvent*>(event);
+        auto *e = static_cast<QHelpEvent*>(event);
         if (m_audioIconDisplayed && m_audioIconRect.contains(e->pos())) {
             QToolTip::showText(e->globalPos(), m_tab->isMuted() ? tr("Unmute Tab") : tr("Mute Tab"), this);
             event->accept();
