@@ -18,12 +18,14 @@
 #include "qztools.h"
 #include "datapaths.h"
 #include "settings.h"
+#include "mainapplication.h"
 
 #include <QTextDocument>
 #include <QDateTime>
 #include <QByteArray>
 #include <QPixmap>
 #include <QPainter>
+#include <QPainterPath>
 #include <QBuffer>
 #include <QFile>
 #include <QDir>
@@ -40,6 +42,7 @@
 #include <QProcess>
 #include <QMessageBox>
 #include <QUrlQuery>
+#include <QtGuiVersion>
 
 #ifdef QZ_WS_X11
 #include <QX11Info>
@@ -65,7 +68,7 @@ QByteArray QzTools::pixmapToByteArray(const QPixmap &pix)
         return buffer.buffer().toBase64();
     }
 
-    return QByteArray();
+    return {};
 }
 
 QPixmap QzTools::pixmapFromByteArray(const QByteArray &data)
@@ -107,7 +110,7 @@ QByteArray QzTools::readAllFileByteContents(const QString &filename)
         return a;
     }
 
-    return QByteArray();
+    return {};
 }
 
 void QzTools::centerWidgetOnScreen(QWidget* w)
@@ -141,7 +144,7 @@ bool QzTools::removeRecursively(const QString &filePath)
     }
     if (fileInfo.isDir() && !fileInfo.isSymLink()) {
         QDir dir(filePath);
-        dir = dir.canonicalPath();
+        dir.setPath(dir.canonicalPath());
         if (dir.isRoot() || dir.path() == QDir::home().canonicalPath()) {
             qCritical() << "Attempt to remove root/home directory" << dir;
             return false;
@@ -201,7 +204,7 @@ QString QzTools::samePartOfStrings(const QString &one, const QString &other)
 {
     int maxSize = qMin(one.size(), other.size());
     if (maxSize <= 0) {
-        return QString();
+        return {};
     }
 
     int i = 0;
@@ -378,23 +381,23 @@ QString QzTools::fileSizeToString(qint64 size)
 
     double _size = size / 1024.0; // KB
     if (_size < 1000) {
-        return QString::number(_size > 1 ? _size : 1, 'f', 0) + " " + QObject::tr("KB");
+        return QString::number(_size > 1 ? _size : 1, 'f', 0) + QLatin1Char(' ') + QObject::tr("KB");
     }
 
     _size /= 1024; // MB
     if (_size < 1000) {
-        return QString::number(_size, 'f', 1) + " " + QObject::tr("MB");
+        return QString::number(_size, 'f', 1) + QLatin1Char(' ') + QObject::tr("MB");
     }
 
     _size /= 1024; // GB
-    return QString::number(_size, 'f', 2) + " " + QObject::tr("GB");
+    return QString::number(_size, 'f', 2) + QLatin1Char(' ') + QObject::tr("GB");
 }
 
 QPixmap QzTools::createPixmapForSite(const QIcon &icon, const QString &title, const QString &url)
 {
     const QFontMetrics fontMetrics = QApplication::fontMetrics();
     const int padding = 4;
-    const int maxWidth = fontMetrics.width(title.length() > url.length() ? title : url) + 3 * padding + 16;
+    const int maxWidth = fontMetrics.horizontalAdvance(title.length() > url.length() ? title : url) + 3 * padding + 16;
     const int width = qMin(maxWidth, 150);
     const int height = fontMetrics.height() * 2 + fontMetrics.leading() + 2 * padding;
 
@@ -511,12 +514,12 @@ QString QzTools::resolveFromPath(const QString &name)
     const QString path = qgetenv("PATH").trimmed();
 
     if (path.isEmpty()) {
-        return QString();
+        return {};
     }
 
-    QStringList dirs = path.split(QLatin1Char(':'), QString::SkipEmptyParts);
+    const QStringList dirs = path.split(QLatin1Char(':'), Qt::SkipEmptyParts);
 
-    foreach (const QString &dir, dirs) {
+    for (const QString &dir : dirs) {
         QDir d(dir);
         if (d.exists(name)) {
             return d.absoluteFilePath(name);
@@ -608,7 +611,7 @@ bool QzTools::isUtf8(const char* string)
 
 bool QzTools::containsSpace(const QString &str)
 {
-    Q_FOREACH (const QChar &c, str) {
+    for (const QChar &c : str) {
         if (c.isSpace())
             return true;
     }
@@ -641,14 +644,14 @@ static QString getFilename(const QString &path)
     }
 
     if (info.isDir()) {
-        return QString();
+        return {};
     }
 
     if (info.dir().exists()) {
         return info.fileName();
     }
 
-    return QString();
+    return {};
 }
 
 QString QzTools::getOpenFileName(const QString &name, QWidget* parent, const QString &caption, const QString &dir, const QString &filter, QString* selectedFilter, QFileDialog::Options options)
@@ -744,7 +747,7 @@ bool QzTools::matchDomain(const QString &pattern, const QString &domain)
     return index > 0 && domain[index - 1] == QLatin1Char('.');
 }
 
-QKeySequence QzTools::actionShortcut(QKeySequence shortcut, QKeySequence fallBack, QKeySequence shortcutRtl, QKeySequence fallbackRtl)
+QKeySequence QzTools::actionShortcut(const QKeySequence &shortcut, const QKeySequence &fallBack, const QKeySequence &shortcutRtl, const QKeySequence &fallbackRtl)
 {
     if (QApplication::isRightToLeft() && (!shortcutRtl.isEmpty() || !fallbackRtl.isEmpty()))
         return shortcutRtl.isEmpty() ? fallbackRtl : shortcutRtl;
@@ -765,7 +768,7 @@ QStringList QzTools::splitCommandArguments(const QString &command)
     QString line = command.trimmed();
 
     if (line.isEmpty()) {
-        return QStringList();
+        return {};
     }
 
     QChar SPACE(' ');
@@ -832,7 +835,7 @@ QStringList QzTools::splitCommandArguments(const QString &command)
 
     // Unmatched quote
     if (inQuote) {
-        return QStringList();
+        return {};
     }
 
     return r;
@@ -847,7 +850,7 @@ bool QzTools::startExternalProcess(const QString &executable, const QString &arg
     if (!success) {
         QString info = "<ul><li><b>%1</b>%2</li><li><b>%3</b>%4</li></ul>";
         info = info.arg(QObject::tr("Executable: "), executable,
-                        QObject::tr("Arguments: "), arguments.join(QLatin1String(" ")));
+                        QObject::tr("Arguments: "), arguments.join(QLatin1Char(' ')));
 
         QMessageBox::critical(0, QObject::tr("Cannot start external program"),
                               QObject::tr("Cannot start external program! %1").arg(info));
@@ -862,8 +865,8 @@ void QzTools::setWmClass(const QString &name, const QWidget* widget)
     if (QGuiApplication::platformName() != QL1S("xcb"))
         return;
 
-    const QByteArray &nameData = name.toUtf8();
-    const QByteArray &classData = QByteArrayLiteral("Falkon");
+    const QByteArray nameData = name.toUtf8();
+    const QByteArray classData = mApp->wmClass().isEmpty() ? QByteArrayLiteral("Falkon") : mApp->wmClass();
 
     uint32_t class_len = nameData.length() + 1 + classData.length() + 1;
     char *class_hint = (char*) malloc(class_len);
@@ -1001,3 +1004,20 @@ QString QzTools::operatingSystemLong()
     return QzTools::operatingSystem() + QSL(" ") + arch;
 }
 
+void QzTools::paintDropIndicator(QWidget *widget, const QRect &r)
+{
+    // Modified code from KFilePlacesView
+    QColor color = widget->palette().brush(QPalette::Normal, QPalette::Highlight).color();
+    const int x = (r.left() + r.right()) / 2;
+    const int thickness = qRound(r.width() / 2.0);
+    int alpha = 255;
+    const int alphaDec = alpha / (thickness + 1);
+    QStylePainter p(widget);
+    for (int i = 0; i < thickness; i++) {
+        color.setAlpha(alpha);
+        alpha -= alphaDec;
+        p.setPen(color);
+        p.drawLine(x - i, r.top(), x - i, r.bottom());
+        p.drawLine(x + i, r.top(), x + i, r.bottom());
+    }
+}
