@@ -82,7 +82,7 @@ FCM_Dialog::FCM_Dialog(FCM_Plugin* manager, QWidget* parent)
     ui->flashCookieTree->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(ui->flashCookieTree, &QWidget::customContextMenuRequested, this, &FCM_Dialog::cookieTreeContextMenuRequested);
 
-    QShortcut* removeShortcut = new QShortcut(QKeySequence("Del"), this);
+    auto* removeShortcut = new QShortcut(QKeySequence("Del"), this);
     connect(removeShortcut, &QShortcut::activated, this, &FCM_Dialog::deletePressed);
 
     QzTools::setWmClass("FlashCookies", this);
@@ -97,7 +97,7 @@ void FCM_Dialog::removeAll()
     }
 
     const QList<FlashCookie> &flashCookies = m_manager->flashCookies();
-    foreach (const FlashCookie &flashCookie, flashCookies) {
+    for (const FlashCookie &flashCookie : flashCookies) {
          m_manager->removeCookie(flashCookie);
     }
 
@@ -118,7 +118,7 @@ void FCM_Dialog::removeCookie()
     if (data.isNull()) {     //Remove whole cookie group
         const QString origin = current->text(0);
         const QList<FlashCookie> &flashCookies = m_manager->flashCookies();
-        foreach (const FlashCookie &flashCookie, flashCookies) {
+        for (const FlashCookie &flashCookie : flashCookies) {
             if (flashCookie.origin == origin) {
                 m_manager->removeCookie(flashCookie);
             }
@@ -215,7 +215,7 @@ void FCM_Dialog::refreshFlashCookiesTree()
 
         QString cookieOrigin = flashCookie.origin;
         if (cookieOrigin.startsWith(QLatin1Char('.'))) {
-            cookieOrigin = cookieOrigin.mid(1);
+            cookieOrigin.remove(0, 1);
         }
 
         QTreeWidgetItem* findParent = hash.value(cookieOrigin);
@@ -223,7 +223,7 @@ void FCM_Dialog::refreshFlashCookiesTree()
             item = new QTreeWidgetItem(findParent);
         }
         else {
-            QTreeWidgetItem* newParent = new QTreeWidgetItem(ui->flashCookieTree);
+            auto* newParent = new QTreeWidgetItem(ui->flashCookieTree);
             newParent->setText(0, cookieOrigin);
             newParent->setIcon(0, IconProvider::standardIcon(QStyle::SP_DirIcon));
             ui->flashCookieTree->addTopLevelItem(newParent);
