@@ -64,10 +64,10 @@ void GM_Manager::showSettings(QWidget* parent)
 
 void GM_Manager::downloadScript(const QUrl &url)
 {
-    GM_Downloader *downloader = new GM_Downloader(url, this);
+    auto *downloader = new GM_Downloader(url, this);
     connect(downloader, &GM_Downloader::finished, this, [=](const QString &fileName) {
         bool deleteScript = true;
-        GM_Script *script = new GM_Script(this, fileName);
+        auto *script = new GM_Script(this, fileName);
         if (script->isValid()) {
             if (!containsScript(script->fullName())) {
                 GM_AddScriptDialog dialog(this, script);
@@ -99,7 +99,7 @@ QString GM_Manager::requireScripts(const QStringList &urlList) const
 {
     QDir requiresDir(m_settingsPath + QL1S("/greasemonkey/requires"));
     if (!requiresDir.exists() || urlList.isEmpty()) {
-        return QString();
+        return {};
     }
 
     QSettings settings(m_settingsPath + QL1S("/greasemonkey/requires/requires.ini"), QSettings::IniFormat);
@@ -107,7 +107,7 @@ QString GM_Manager::requireScripts(const QStringList &urlList) const
 
     QString script;
 
-    foreach (const QString &url, urlList) {
+    for (const QString &url : urlList) {
         if (settings.contains(url)) {
             QString fileName = settings.value(url).toString();
             if (!QFileInfo(fileName).isAbsolute()) {
@@ -158,7 +158,7 @@ QList<GM_Script*> GM_Manager::allScripts() const
 
 bool GM_Manager::containsScript(const QString &fullName) const
 {
-    foreach (GM_Script* script, m_scripts) {
+    for (GM_Script* script : qAsConst(m_scripts)) {
         if (fullName == script->fullName()) {
             return true;
         }
@@ -197,7 +197,7 @@ bool GM_Manager::addScript(GM_Script* script)
     QWebEngineScriptCollection *collection = mApp->webProfile()->scripts();
     collection->insert(script->webScript());
 
-    emit scriptsChanged();
+    Q_EMIT scriptsChanged();
     return true;
 }
 
@@ -219,7 +219,7 @@ bool GM_Manager::removeScript(GM_Script* script, bool removeFile)
         delete script;
     }
 
-    emit scriptsChanged();
+    Q_EMIT scriptsChanged();
     return true;
 }
 
@@ -248,9 +248,10 @@ void GM_Manager::load()
     settings.beginGroup("GreaseMonkey");
     m_disabledScripts = settings.value("disabledScripts", QStringList()).toStringList();
 
-    foreach (const QString &fileName, gmDir.entryList(QStringList("*.js"), QDir::Files)) {
+    const auto fileNames = gmDir.entryList(QStringList("*.js"), QDir::Files);
+    for (const QString &fileName : fileNames) {
         const QString absolutePath = gmDir.absoluteFilePath(fileName);
-        GM_Script* script = new GM_Script(this, absolutePath);
+        auto* script = new GM_Script(this, absolutePath);
 
         if (!script->isValid()) {
             delete script;
@@ -273,7 +274,7 @@ void GM_Manager::load()
 
 void GM_Manager::scriptChanged()
 {
-    GM_Script *script = qobject_cast<GM_Script*>(sender());
+    auto *script = qobject_cast<GM_Script*>(sender());
     if (!script)
         return;
 
@@ -290,7 +291,7 @@ bool GM_Manager::canRunOnScheme(const QString &scheme)
 
 void GM_Manager::mainWindowCreated(BrowserWindow* window)
 {
-    GM_Icon *icon = new GM_Icon(this);
+    auto *icon = new GM_Icon(this);
     window->statusBar()->addButton(icon);
     window->navigationBar()->addToolButton(icon);
     m_windows[window] = icon;
