@@ -24,7 +24,8 @@
 #include "tabwidget.h"
 #include "webtab.h"
 #include "../config.h"
-#include "desktopfile.h"
+
+#include <QtWebEngineWidgetsVersion>
 
 GM_Plugin::GM_Plugin()
     : QObject()
@@ -32,11 +33,6 @@ GM_Plugin::GM_Plugin()
 {
 }
 
-DesktopFile GM_Plugin::metaData() const
-{
-    return DesktopFile(QSL(":gm/metadata.desktop"));
-}
-
 void GM_Plugin::init(InitState state, const QString &settingsPath)
 {
     m_manager = new GM_Manager(settingsPath, this);
@@ -46,7 +42,8 @@ void GM_Plugin::init(InitState state, const QString &settingsPath)
 
     // Make sure userscripts works also with already created WebPages
     if (state == LateInitState) {
-        foreach (BrowserWindow *window, mApp->windows()) {
+        const auto windows = mApp->windows();
+        for (BrowserWindow *window : windows) {
             m_manager->mainWindowCreated(window);
         }
     }
@@ -74,7 +71,9 @@ bool GM_Plugin::acceptNavigationRequest(WebPage *page, const QUrl &url, QWebEngi
     Q_UNUSED(page)
     Q_UNUSED(isMainFrame)
 
-    if (type == QWebEnginePage::NavigationTypeLinkClicked && url.toString().endsWith(QLatin1String(".user.js"))) {
+    bool navigationType = type == QWebEnginePage::NavigationTypeLinkClicked || type == QWebEnginePage::NavigationTypeRedirect;
+
+    if (navigationType && url.toString().endsWith(QLatin1String(".user.js"))) {
         m_manager->downloadScript(url);
         return false;
     }
