@@ -23,7 +23,6 @@
 #include "mainapplication.h"
 #include "autofill.h"
 #include "passwordmanager.h"
-#include "desktopfile.h"
 #include "kioschemehandler.h"
 #include "webpage.h"
 #include "webview.h"
@@ -31,25 +30,15 @@
 #include <KCrash>
 #include <KAboutData>
 #include <KProtocolInfo>
-#include <PurposeWidgets/Menu>
 #include <Purpose/AlternativesModel>
 
 #include <QWebEngineProfile>
 #include <QMenu>
+#include <QJsonArray>
 
 KDEFrameworksIntegrationPlugin::KDEFrameworksIntegrationPlugin()
     : QObject()
-    , m_backend(0)
-    , m_sharePageMenu(new Purpose::Menu())
 {
-    m_sharePageMenu->setTitle(tr("Share page"));
-    m_sharePageMenu->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
-    m_sharePageMenu->model()->setPluginType(QStringLiteral("ShareUrl"));
-}
-
-DesktopFile KDEFrameworksIntegrationPlugin::metaData() const
-{
-    return DesktopFile(QSL(":kdeframeworksintegration/metadata.desktop"));
 }
 
 void KDEFrameworksIntegrationPlugin::init(InitState state, const QString &settingsPath)
@@ -70,12 +59,17 @@ void KDEFrameworksIntegrationPlugin::init(InitState state, const QString &settin
         if (WebPage::internalSchemes().contains(protocol)) {
             continue;
         }
-        KIOSchemeHandler *handler = new KIOSchemeHandler(protocol, this);
+        auto *handler = new KIOSchemeHandler(protocol, this);
         m_kioSchemeHandlers.append(handler);
         mApp->webProfile()->installUrlSchemeHandler(protocol.toUtf8(), handler);
         WebPage::addSupportedScheme(protocol);
     }
 
+    m_sharePageMenu = new Purpose::Menu();
+    m_sharePageMenu->setTitle(tr("Share page"));
+    m_sharePageMenu->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
+    m_sharePageMenu->model()->setPluginType(QStringLiteral("ShareUrl"));
+
     KAboutData aboutData(QSL("falkon"), QSL("Falkon"), QCoreApplication::applicationVersion());
     KAboutData::setApplicationData(aboutData);
 
@@ -102,7 +96,7 @@ void KDEFrameworksIntegrationPlugin::populateWebViewMenu(QMenu *menu, WebView *v
     Q_UNUSED(r)
 
     m_sharePageMenu->model()->setInputData(QJsonObject{
-        { QStringLiteral("urls"), QJsonValue(view->url().toString()) },
+        { QStringLiteral("urls"), QJsonArray {QJsonValue(view->url().toString())} },
         { QStringLiteral("title"), QJsonValue(view->title()) }
     });
     m_sharePageMenu->reload();
